@@ -31,15 +31,25 @@ enum {
 };
 
 typedef struct {
-    float cur_x, cur_y; /* float position IN bowl */
-    int check_y; /* block y IN BOWL that is used to check insertion/validate position/etc */
     int sx, sy; /* screen position */
     int sw, sh; /* tile size in pixels */
     int x, y; /* map position */
+    float cur_y; /* float pixel y position IN bowl */
     int id; /* picture&structure id */
     int rot_id; /* 0 - 3 rotation positions */
 } Block;
 
+typedef struct {
+	int transition; /* lines until first transition */
+	int pieces; /* pieces placed */
+	int i_pieces; /* how many i pieces */
+	int cleared[4]; /* singles, doubles, triples, tetris */
+	int tetris_rate; /* how many lines in tetrises */
+	int droughts; /* number of droughts */
+	int max_drought; /* max length of droughts */
+	int sum_droughts; /* sum of all droughts for average */
+} BowlStats;
+
 typedef struct {
     int mute; /* if mute no sounds are played */
     int blind; /* if this is true all graphical stuff called in a function not 
@@ -50,21 +60,27 @@ typedef struct {
     int w, h; /* measurements in blocks */
     int block_size; /* blocksize in pixels */
     Controls *controls; /* reacts to these controls */
+    int das_charge; /* current charge in ms */
+    int das_maxcharge; /* maximum charge in ms */
+    int das_drop; /* das charge drop if shifting piece */
+    int are; /* in ms, if > 0 next piece is blocked until delay times out */
+    int lock_delay; /* time on collision until piece is inserted */
     int stored_key; /* key that was stored this programme cycle */
     SDL_Surface *blocks; /* pointer to the block graphics */
-    SDL_Surface *unknown_preview; /* if preview's unknown this is displaye */
-    char name[32]; /* player's name playing at this bowl */
+    SDL_Surface *unknown_preview; /* if preview's unknown this is displayed */
+    char name[32]; /* player's name for this bowl */
     Counter score; /* score gained by this player */
-    int level; /* level to which player has played */
-    int lines;
+    int level; /* level to which player has played (starts at 0) */
+    int firstlevelup_lines; /* number of lines needed for first level up */
+    int lines; /* number of cleared lines in total */
+    int cleared_line_y[4]; /* line indices of cleared lines for last insertion */
+    int cleared_line_count; /* how many lines where cleared */
     int use_figures; /* draw a figure each new level? */
     int add_lines, add_tiles; /* add lines or tiles after time out? */
     int add_line_holes; /* number of holes in added line */
     int dismantle_saves; /* if a line was removed the delay is reset */
     Delay add_delay; /* delay until next add action */
     int contents[BOWL_WIDTH][BOWL_HEIGHT]; /* indices of blocks or -1 */
-    int pixel_contents[BOWL_WIDTH][BOWL_HEIGHT * BOWL_BLOCK_SIZE]; /* width is always discret but vertical movement 
-                                                                      smooth needs all pixels of a row for a fast check */
     Block block;/* current block */
     Delay block_hori_delay; /* horizontal movement delay */
     int next_block_id; /* id of next block */
@@ -79,12 +95,8 @@ typedef struct {
     int paused;
     int draw_contents; /* set if bowl needs a full redraw next bowl_show() */
     int help_sx, help_sy, help_sw, help_sh; /* position of helping shadow */
-    float help_alpha;
-    float help_alpha_change;
     int preview_center_sx, preview_center_sy; /* preview is centered here if preview_center_x != -1  */
     int preview_sx, preview_sy; /* actuall preview is drawn here */
-    float preview_alpha;
-    float preview_alpha_change;
     int cpu_dest_x; /* move block to this position (computed in bowl_select_next_block() */
     int cpu_dest_rot; /* destination rotation */
     int cpu_dest_score; /* AI score */
@@ -98,6 +110,14 @@ typedef struct {
     Sound_Chunk *wav_nextlevel;
     Sound_Chunk *wav_excellent;
 #endif
+
+    /* statistics */
+    int stats_x, stats_y, stats_w, stats_h;
+    BowlStats stats;
+    int drought; /* current drought: pieces since last i piece */
+
+    /* training */
+    int zero_gravity;
 } Bowl;
 
 /*
@@ -182,4 +202,17 @@ Play an optimized mute game. (used for stats)
 */
 void bowl_quick_game( Bowl *bowl, int aggr );
 
+/*
+====================================================================
+Actually insert block and remove a line if needed,
+create shrapnells, give score etc
+If game is over only insert block.
+====================================================================
+*/
+void bowl_insert_block( Bowl *bowl );
+
+void bowl_draw_stats(Bowl *bowl);
+
+void bowl_toggle_gravity(Bowl *bowl);
+
 #endif
