@@ -32,8 +32,8 @@ Config config;
 #define CONFIG_FILE_NAME "ltris.conf"
 
 /* game type names. hacky place to define them but who cares? */
-char gametype_names[8][64];
-char gametype_ids[8][64];
+char gametype_names[GAME_TYPENUM][64];
+char gametype_ids[GAME_TYPENUM][64];
 
 /* check if config directory exists; if not create it and set config_dir */
 void config_check_dir()
@@ -65,12 +65,11 @@ void config_reset()
     config.gametype = GAME_DEMO;
     config.starting_level = 0;
     config.preview = 1;
-    config.help = 1;
-    config.slow = 0;
     strcpy( config.player1.name, "Michael" );
     strcpy( config.player2.name, "Sabine" );
     strcpy( config.player3.name, "Thomas" );
     config.expert = 0;
+    config.modern = 1;
     /* multiplayer */
     config.holes = 2;
     config.rand_holes = 1;
@@ -105,14 +104,13 @@ void config_reset()
     /* sound */
     config.sound = 1;
     config.volume = 6; /* 1 - 8 */
+    config.shiftsound = 1;
     /* graphics */
-    config.trp = 1;
     config.anim = 1;
     config.fullscreen = 0;
     config.fade = 1;
-    config.fps = 0; /* frames per second: 0 - no limit, 1 - 50, 2 - 100, 3 - 200 */
+    config.fps = 0; /* frames per second: 0 - 60Hz, 1 - 50Hz */
     config.bkgnd = 0;
-    config.smooth_hori = 0;
     config.block_by_block = 0;
     /* lbreakout2 event data */
     config.rel_motion = 0;
@@ -123,9 +121,7 @@ void config_reset()
     config.quick_help = 1;
     config.visualize = 0;
     config.keep_bkgnd = 0;
-    config.clear_keystate = 1;
     config.center_preview = 0;
-    config.async_col_check = 0;
 }
 
 /* load config */
@@ -160,12 +156,11 @@ void config_load( )
     /* parse config */
     parser_get_int( pd, "gametype", &config.gametype );
     parser_get_int( pd, "starting_level", &config.starting_level );
-    if (config.starting_level > 9 || config.starting_level < 0) {
+    if (config.starting_level > 19 || config.starting_level < 0) {
 	    config.starting_level = 0;
     }
     parser_get_int( pd, "preview", &config.preview );
-    parser_get_int( pd, "help", &config.help );
-    parser_get_int( pd, "expert", &config.expert );
+    parser_get_int( pd, "modern", &config.modern );
     parser_get_int( pd, "center_preview", &config.center_preview );
     parser_get_int( pd, "holes", &config.holes );
     parser_get_int( pd, "rand_holes", &config.rand_holes );
@@ -177,20 +172,18 @@ void config_load( )
         parse_player( sub, &config.player2 );
     if ( parser_get_pdata( pd, "player3", &sub ) )
         parse_player( sub, &config.player3 );
-    parser_get_int( pd, "clear_keystate", &config.clear_keystate );
     parser_get_int( pd, "cpu_aggr", &config.cpu_aggr );
     parser_get_int( pd, "cpu_delay", &config.cpu_delay );
     parser_get_int( pd, "cpu_rot_delay", &config.cpu_rot_delay );
     parser_get_int( pd, "sound", &config.sound );
     parser_get_int( pd, "volume", &config.volume );
-    parser_get_int( pd, "transparency", &config.trp );
+    parser_get_int( pd, "shiftsound", &config.shiftsound );
     parser_get_int( pd, "animations", &config.anim );
     parser_get_int( pd, "fullscreen", &config.fullscreen );
     parser_get_int( pd, "fading", &config.fade );
     parser_get_int( pd, "fps", &config.fps );
     parser_get_int( pd, "background", &config.bkgnd );
     parser_get_int( pd, "static_background", &config.keep_bkgnd );
-    parser_get_int( pd, "smooth_hori", &config.smooth_hori );
     parser_get_int( pd, "hori_delay", &config.hori_delay );
     parser_get_int( pd, "vert_delay", &config.vert_delay );
     parser_get_int( pd, "pause_key", &config.pause_key );
@@ -200,7 +193,6 @@ void config_load( )
     parser_get_int( pd, "grap_input", &config.grab );
     parser_get_int( pd, "invert_mouse", &config.invert );
     parser_get_int( pd, "quick_help", &config.quick_help );
-    parser_get_int( pd, "async_collision_check", &config.async_col_check );
     parser_free( &pd );
 }
 
@@ -208,14 +200,14 @@ void config_load( )
 static void print_player( FILE *file, int i, Player *player )
 {
     fprintf( file, "<player%i\n", i );
-    fprintf( file, "name%s\n", player->name );
+    fprintf( file, "name=%s\n", player->name );
     fprintf( file, "<controls\n" );
-    fprintf( file, "left%i\n", player->controls.left );
-    fprintf( file, "right%i\n", player->controls.right );
-    fprintf( file, "rot_left%i\n", player->controls.rot_left );
-    fprintf( file, "rot_right%i\n", player->controls.rot_right );
-    fprintf( file, "down%i\n", player->controls.down );
-    fprintf( file, "drop%i\n", player->controls.drop );
+    fprintf( file, "left=%i\n", player->controls.left );
+    fprintf( file, "right=%i\n", player->controls.right );
+    fprintf( file, "rot_left=%i\n", player->controls.rot_left );
+    fprintf( file, "rot_right=%i\n", player->controls.rot_right );
+    fprintf( file, "down=%i\n", player->controls.down );
+    fprintf( file, "drop=%i\n", player->controls.drop );
     fprintf( file, ">\n" );
     fprintf( file, ">\n" );
 }
@@ -229,42 +221,38 @@ void config_save( )
         fprintf( stderr, "Cannot access config file '%s' to save settings\n", file_name );
     else {
         fprintf( file, "@\n" );
-        fprintf( file, "gametype%i\n", config.gametype );
-        fprintf( file, "starting_level%i\n", config.starting_level );
-        fprintf( file, "preview%i\n", config.preview );
-        fprintf( file, "help%i\n", config.help );
-        fprintf( file, "expert%i\n", config.expert );
-        fprintf( file, "center_preview%i\n", config.center_preview );
-        fprintf( file, "holes%i\n", config.holes );
-        fprintf( file, "rand_holes%i\n", config.rand_holes );
-        fprintf( file, "send_all%i\n", config.send_all );
-        fprintf( file, "send_tetris%i\n", config.send_tetris );
+        fprintf( file, "gametype=%i\n", config.gametype );
+        fprintf( file, "starting_level=%i\n", config.starting_level );
+        fprintf( file, "preview=%i\n", config.preview );
+        fprintf( file, "modern=%i\n", config.modern );
+        fprintf( file, "center_preview=%i\n", config.center_preview );
+        fprintf( file, "holes=%i\n", config.holes );
+        fprintf( file, "rand_holes=%i\n", config.rand_holes );
+        fprintf( file, "send_all=%i\n", config.send_all );
+        fprintf( file, "send_tetris=%i\n", config.send_tetris );
         print_player( file, 1, &config.player1 );
         print_player( file, 2, &config.player2 );
         print_player( file, 3, &config.player3 );
-        fprintf( file, "clear_keystate%i\n", config.clear_keystate );
-        fprintf( file, "cpu_aggr%i\n", config.cpu_aggr );
-        fprintf( file, "cpu_delay%i\n", config.cpu_delay );
-        fprintf( file, "cpu_rot_delay%i\n", config.cpu_rot_delay );
-        fprintf( file, "sound%i\n", config.sound );
-        fprintf( file, "volume%i\n", config.volume );
-        fprintf( file, "transparency%i\n", config.trp );
-        fprintf( file, "animations%i\n", config.anim );
-        fprintf( file, "fullscreen%i\n", config.fullscreen );
-        fprintf( file, "fading%i\n", config.fade );
-        fprintf( file, "fps%i\n", config.fps );
-        fprintf( file, "background%i\n", config.bkgnd );
-        fprintf( file, "static_background%i\n", config.keep_bkgnd );
-        fprintf( file, "smooth_hori%i\n", config.smooth_hori );
-        fprintf( file, "hori_delay%i\n", config.hori_delay );
-        fprintf( file, "vert_delay%i\n", config.vert_delay );
-        fprintf( file, "pause_key%i\n", config.pause_key );
-        fprintf( file, "block_by_block%i\n", config.block_by_block );
-        fprintf( file, "motion_mod%i\n", config.motion_mod );
-        fprintf( file, "relative_motion%i\n", config.rel_motion );
-        fprintf( file, "grab_input%i\n", config.grab );
-        fprintf( file, "invert_mouse%i\n", config.invert );
-        fprintf( file, "quick_help%i\n", config.quick_help );
-        fprintf( file, "async_collision_check%i\n", config.async_col_check );
+        fprintf( file, "cpu_aggr=%i\n", config.cpu_aggr );
+        fprintf( file, "cpu_delay=%i\n", config.cpu_delay );
+        fprintf( file, "cpu_rot_delay=%i\n", config.cpu_rot_delay );
+        fprintf( file, "sound=%i\n", config.sound );
+        fprintf( file, "volume=%i\n", config.volume );
+        fprintf( file, "shiftsound=%i\n", config.shiftsound );
+        fprintf( file, "animations=%i\n", config.anim );
+        fprintf( file, "fullscreen=%i\n", config.fullscreen );
+        fprintf( file, "fading=%i\n", config.fade );
+        fprintf( file, "fps=%i\n", config.fps );
+        fprintf( file, "background=%i\n", config.bkgnd );
+        fprintf( file, "static_background=%i\n", config.keep_bkgnd );
+        fprintf( file, "hori_delay=%i\n", config.hori_delay );
+        fprintf( file, "vert_delay=%i\n", config.vert_delay );
+        fprintf( file, "pause_key=%i\n", config.pause_key );
+        fprintf( file, "block_by_block=%i\n", config.block_by_block );
+        fprintf( file, "motion_mod=%i\n", config.motion_mod );
+        fprintf( file, "relative_motion=%i\n", config.rel_motion );
+        fprintf( file, "grab_input=%i\n", config.grab );
+        fprintf( file, "invert_mouse=%i\n", config.invert );
+        fprintf( file, "quick_help=%i\n", config.quick_help );
     }
 }
