@@ -28,7 +28,8 @@ enum {
     GAME_VS_HUMAN_HUMAN,
     GAME_VS_HUMAN_CPU,
     GAME_VS_CPU_CPU,
-    GAME_LAST
+    GAME_TRAINING,
+    GAME_TYPENUM
 };
 
 typedef struct {
@@ -53,12 +54,11 @@ typedef struct {
     int gametype;
     int starting_level;
     int preview;
+    int modern;
     int expert;
     Player player1;
     Player player2;
     Player player3;
-    int help;
-    int slow;
     /* multiplayer */
     int holes;
     int rand_holes;
@@ -75,15 +75,14 @@ typedef struct {
     /* sound */
     int sound;
     int volume; /* 1 - 8 */
+    int shiftsound;
     /* graphics */
-    int trp;
     int anim;
     int fullscreen;
     int fade;
     int fps; /* frames per second: 0 - no limit, 1 - 50, 2 - 100, 3 - 200 */
-	int bkgnd;
-	int smooth_hori;
-	int block_by_block;
+    int bkgnd;
+    int block_by_block;
     /* lbreakout2 event data */
     int motion_mod;
     int rel_motion;
@@ -93,9 +92,7 @@ typedef struct {
     int quick_help;
     int visualize; /* compute stats hidden? */
     int keep_bkgnd;
-    int clear_keystate;
     int center_preview;
-    int async_col_check;
 } Config;
 
 /* config directory name in home directory */
