@@ -64,14 +64,14 @@ Hint strings for the menu.
 */
 #define HINT_ 0
 #define HINT_QHELP _("Enable/disable these quick hints.")
-#define HINT_CTRLS _("Set player controls and horizontal speed.")
+#define HINT_CTRLS _("Set player controls.")
 #define HINT_GFX   _("Here you may customize the graphical appearance of LTris.")
 #define HINT_AUDIO _("Audio Settings.")
 #define HINT_QUIT _("Get back to nasty work.")
 #define HINT_NEWGAME _("Setup and run a cool game!")
-#define HINT_ANIM _("If animations disturb you you may turn them off.")
+#define HINT_ANIM _("Simple will remove pieces sideways while Normal is a bit more fancy but might block the view.")
 #define HINT_DISPLAY _("You may play LTris either in window of fullscreen mode.")
-#define HINT_FPS _("If you don't want LTris to consume all of your CPU limit the frame rate.")
+#define HINT_FPS _("Change frames per second.")
 #define HINT_SMOOTHHORI _("Horizontally move block either tile-by-tile or smooth. This is just eye-candy and doesn't effect the moving speed at all.")
 #define HINT_SMOOTHVERT _("Drop block tile-by-tile or smooth.##NOTE: While tile-by-tile allows you to move a block below a tile multiple times you'll only be able to do so one time when choosing 'smooth'!#See 'Advanced Options/Collision Check' to improve this.")
 #define HINT_HORIDEL _("The less delay you take the faster the block will horizontally move and the more sensitive the input is handled.")
@@ -80,8 +80,11 @@ Hint strings for the menu.
 #define HINT_PAUSEKEY _("Key used to pause and unpause a game.")
 #define HINT_START _("Let's get it on!!!!")
 #define HINT_NAME _("Human player names. If you play against CPU it will be named as CPU-x.")
-#define HINT_STARTLEVEL _("This is your starting level which will be ignored for game 'Figures' (you'll always start at level 0 there).##Each starting level up adds you 1.5% score in the end!")
-#define HINT_PREVIEW _("Enable/Disable block preview.##If disabled you'll gain 15% score in the end!")
+#define HINT_STARTLEVEL _("This is your starting level which will be ignored "\
+			"for mode 'Figures' (always start at level 0).##"\
+			"If not 0 the first level transition will require more lines to be cleared "\
+			"(the higher the starting level the more lines).")
+#define HINT_PREVIEW _("Enable/Disable piece preview.##If disabled you'll instantly gain 20% score when clearing lines.")
 #define HINT_HELP _("Shows guiding lines or a shadow of the currently dropping block so you see where it'll hit the ground.##This option has no penalty/bonus.")
 #define HINT_MPMENU _("Some multiplayer and CPU settings.")
 #define HINT_HOLES _("A line send to your opponent's bowl will have this number of holes in it. The more holes the harder it will be to remove this line so you should choose a low value (e.g. 1 or 2) for long multiplayer games.")
@@ -93,12 +96,13 @@ Hint strings for the menu.
 #define HINT_ADV _("Some advanced options.")
 #define HINT_CPUALG _("Test the CPU analyze algorithm in cpu.c and give an average score for a number of games.")
 #define HINT_VIS _("If you turn visualization off the results will be computed faster. If you turn them on you can see a general game behaviour and judge the algorithm by this behaviour.")
-#define HINT_GAME _("There are basically three different game types:##CLASSIC:#The classic tetris game. Starts with an empty bowl and goes "\
-                  "as long as you make it.#FIGURES:#Each level a nice figure will be added to the ground of you bowl. From level "\
+#define HINT_GAMEMODE _("There are basically three different game types:##NORMAL:#Starts with an empty bowl and goes "\
+                  "as long as you can make it.#FIGURES:#Each level a nice figure will be added to the ground of you bowl. From level "\
                   "7-12 there will be randomly appearing single tiles and from level 13-... there will be whole lines appearing at the "\
                   "bottom of your bowl. Fun!#TWO/THREE-PLAYER:#Either play against other humans or CPU. If you complete multiple lines they'll "\
                   "be send to your opponents according to the multiplayer settings you made.##"\
-                  "And in DEMO you can see your CPU do the work. So relax! ;-)")
+                  "In DEMO you can see your CPU do the work. So relax! ;-)##"\
+		  "In TRAINING you can disable gravity (key for hard drop) to think about piece placement.")
 #define HINT_BKGND _("If you turn this on the background will change every level else it's always the same.")
 #define HINT_KEYSTATE _("If you enable this option the keystate of either the 'Down' key or all the keys are cleared so you can't accidently move the next block.")
 #define HINT_CENTERPREVIEW _("If this is enabled the preview in Two-Player is centered in the middle of the screen instead that one is drawn at the bottom and one at the top.")
@@ -111,6 +115,13 @@ Hint strings for the menu.
 			"current bag (a bag is a set of all 7 randomly sorted basic pieces) "\
 			"is dealt out next. This option only works for single player. "\
 			"There is a 50% score bonus in the end.")
+#define HINT_GAMESTYLE _("Modern enables all that stuff that makes tetris "\
+			"casual like piece shadow, wall-kicks, "\
+			"DAS charge during ARE (allows to shift next piece faster), "\
+			"piece bag (at max 12 pieces before getting same piece again).##"\
+			"Classic doesn't give you any of this making the game "\
+			"really hard but also very interesting.")
+#define HINT_SHIFTSOUND _("Enable/Disable piece shift sound.")
                        
 /*
 ====================================================================
@@ -210,10 +221,8 @@ void manager_create()
     Item *item;
     int filter[SDLK_LAST]; /* key filter */
     /* constant contence of switches */
-    char *str_fps[] = { _("No Limit"), _("50 FPS"), _("100 FPS"), _("200 FPS") ,};
+    char *str_fps[] = { _("60 FPS"), _("50 FPS") };
     char *str_cpu_aggr[] = { _("Defensive"), _("Normal"), _("Aggressive"), _("Kamikaze") ,};
-    char *str_help[] = { _("Off"), _("Shadow"), _("Lines") ,};
-    char *keystate_names[] = { _("None"), _("Down"), _("All") ,};
 
     char aux[128];
     int i, j, k, l;
@@ -231,14 +240,15 @@ void manager_create()
     Menu *cont = 0;
     Menu *cont_player1 = 0, *cont_player2 = 0, *cont_player3 = 0;
     Menu *twoplayer = 0;
-    char *lc_gametype_names[8] = {gametype_names[0],
+    char *lc_gametype_names[GAME_TYPENUM] = {gametype_names[0],
         gametype_names[1],
         gametype_names[2],
         gametype_names[3],
         gametype_names[4],
         gametype_names[5],
         gametype_names[6],
-        gametype_names[7]};
+        gametype_names[7],
+	gametype_names[8]};
     
     /* load graphics and sounds */
     mbkgnd = load_surf( "menuback.bmp", SDL_SWSURFACE );
@@ -308,8 +318,8 @@ void manager_create()
     menu_add( _main, item_create_separator  ( _("Audio") ) );
 #endif
     menu_add( _main, item_create_separator  ( "" ) );
-    menu_add( _main, item_create_link       ( _("Advanced Options"), HINT_ADV, adv ) );
-    menu_add( _main, item_create_separator  ( "" ) );
+    //menu_add( _main, item_create_link       ( _("Advanced Options"), HINT_ADV, adv ) );
+    //menu_add( _main, item_create_separator  ( "" ) );
     menu_add( _main, item_create_action     ( _("Quit"), HINT_QUIT, ACTION_QUIT ) );
 #ifdef _1
     /* options */
@@ -328,19 +338,23 @@ void manager_create()
     item = item_create_range( _("Volume:"), HINT_, &config.volume, 1, 8, 1 );
     item->callback = cb_volume;
     menu_add( audio, item );
+    menu_add(audio, item_create_switch( _("Shift Sound:"), HINT_SHIFTSOUND, &config.shiftsound, _("Off"), _("On") ));
     menu_add( audio, item_create_separator( "" ) );
     menu_add( audio, item_create_link( _("Back"), HINT_, _main ) );
 #endif
     /* gfx */
-    menu_add( gfx, item_create_switch( _("Animations:"), HINT_ANIM, &config.anim, _("Off"), _("On") ) );
-    menu_add( gfx, item_create_switch( _("Move:"), HINT_SMOOTHHORI, &config.smooth_hori, _("Tile By Tile"), _("Smooth") ) );
+    menu_add( gfx, item_create_switch( _("Animations:"), HINT_ANIM, &config.anim, _("Simple"), _("Normal") ) );
+    //menu_add( gfx, item_create_switch( _("Move:"), HINT_SMOOTHHORI, &config.smooth_hori, _("Tile By Tile"), _("Smooth") ) );
     menu_add( gfx, item_create_switch( _("Drop:"), HINT_SMOOTHVERT, &config.block_by_block, _("Smooth"), _("Tile By Tile") ) );
-    menu_add( gfx, item_create_switch( _("Change Background:"), HINT_BKGND, &config.keep_bkgnd, _("Yes"), _("No") ) );
+    //menu_add( gfx, item_create_switch( _("Change Background:"), HINT_BKGND, &config.keep_bkgnd, _("Yes"), _("No") ) );
+    item = item_create_switch  ( _("Quick Help:"), HINT_QHELP, &config.quick_help, _("Off"), _("On") );
+    item->callback = cb_hints;
+    menu_add( gfx, item );
     menu_add( gfx, item_create_separator( "" ) );
     item = item_create_switch( _("Display:"), HINT_DISPLAY, &config.fullscreen, _("Window"), _("Fullscreen") );
     item->callback = cb_fullscreen;
     menu_add( gfx, item );
-    menu_add( gfx, item_create_switch_x( _("Frame Rate:"), HINT_FPS, &config.fps, str_fps, 4 ) );
+    menu_add( gfx, item_create_switch_x( _("Frame Rate:"), HINT_FPS, &config.fps, str_fps, 2 ) );
     menu_add( gfx, item_create_separator( "" ) );
     menu_add( gfx, item_create_link( _("Back"), HINT_, _main ) );
     /* game */
@@ -350,15 +364,11 @@ void manager_create()
     menu_add( game, item_create_edit( _("2nd Player:"), HINT_NAME, config.player2.name, 12 ) );
     menu_add( game, item_create_edit( _("3rd Player:"), HINT_NAME, config.player3.name, 12 ) );
     menu_add( game, item_create_separator( "" ) );
-    menu_add( game, item_create_switch_x( _("Game:"), HINT_GAME, &config.gametype, lc_gametype_names, 8 ) );
-    menu_add( game, item_create_range( _("Starting Level:"), HINT_STARTLEVEL, &config.starting_level, 0, 9, 1 ) );
+    menu_add( game, item_create_switch( _("Game Style:"), HINT_GAMESTYLE, &config.modern, _("Classic"), _("Modern") ) );
+    menu_add( game, item_create_switch_x( _("Game Mode:"), HINT_GAMEMODE, &config.gametype, lc_gametype_names, GAME_TYPENUM ) );
+    menu_add( game, item_create_range( _("Starting Level:"), HINT_STARTLEVEL, &config.starting_level, 0, 19, 1 ) );
     menu_add( game, item_create_switch( _("Preview:"), HINT_PREVIEW, &config.preview, _("Off"), _("On") ) );
-    menu_add( game, item_create_switch_x( _("Help:"), HINT_HELP, &config.help, str_help, 3 ) );
-    menu_add( game, item_create_switch( _("Expert Mode:"), HINT_EXPERT, &config.expert, _("Off"), _("On") ) );
-#ifdef _1    
-    menu_add( game, item_create_switch( _("Slow:"), HINT_, &config.slow, _("Off"), _("On") ) );
-#endif    
-    //menu_add( game, item_create_separator( "" ) );
+    menu_add( game, item_create_separator( "" ) );
     menu_add( game, item_create_link( _("Multiplayer Options"), HINT_MPMENU, twoplayer ) );
     menu_add( game, item_create_separator( "" ) );
     menu_add( game, item_create_link( _("Back"), HINT_, _main ) );
@@ -369,6 +379,8 @@ void manager_create()
     menu_add( twoplayer, item_create_switch( _("Send All Lines:"), HINT_SENDALL, &config.send_all, _("Off"), _("On") ) );
     menu_add( twoplayer, item_create_switch( _("Always Send Tetris:"), HINT_SENDTETRIS, &config.send_tetris, _("Off"), _("On") ) );
     menu_add( twoplayer, item_create_separator( "" ) );
+    menu_add( twoplayer, item_create_switch  ( _("Center Preview:"), HINT_CENTERPREVIEW, &config.center_preview, _("Off"), _("On") ) );
+    menu_add( twoplayer, item_create_separator( "" ) );
     menu_add( twoplayer, item_create_switch_x( _("CPU Style:"), HINT_CPUAGGR, &config.cpu_aggr, str_cpu_aggr, 4 ) );
     menu_add( twoplayer, item_create_range( _("CPU Drop Delay:"), HINT_CPUDROP, &config.cpu_delay, 0, 2000, 100 ) );
     menu_add( twoplayer, item_create_separator( "" ) );
@@ -413,8 +425,8 @@ void manager_create()
     menu_add( cont, item_create_link( _("Player2"), HINT_CONTROLS, cont_player2 ) );
     menu_add( cont, item_create_link( _("Player3"), HINT_CONTROLS, cont_player3 ) );
     menu_add( cont, item_create_separator( "" ) );
-    menu_add( cont, item_create_range( _("Horizontal Delay:"),  HINT_HORIDEL,&config.hori_delay, 0, 9, 1 ) );
-    menu_add( cont, item_create_range( _("Vertical Delay:"),  HINT_VERTDEL,&config.vert_delay, 0, 9, 1 ) );
+    //menu_add( cont, item_create_range( _("Horizontal Delay:"),  HINT_HORIDEL,&config.hori_delay, 0, 9, 1 ) );
+    //menu_add( cont, item_create_range( _("Vertical Delay:"),  HINT_VERTDEL,&config.vert_delay, 0, 9, 1 ) );
     menu_add( cont, pause_key );
     menu_add( cont, item_create_separator( "" ) );
     menu_add( cont, item_create_link( _("Back"), HINT_, _main ) );
@@ -434,12 +446,6 @@ void manager_create()
     menu_add( cont_player3, item_create_separator( "" ) );
     menu_add( cont_player3, item_create_link( _("Back"), HINT_, cont ) );
     /* advanced options */
-    item = item_create_switch  ( _("Quick Help:"), HINT_QHELP, &config.quick_help, _("Off"), _("On") );
-    item->callback = cb_hints;
-    menu_add( adv, item );
-    menu_add( adv, item_create_switch_x( _("Clear Keystate:"), HINT_KEYSTATE, &config.clear_keystate, keystate_names, 3 ) );
-    menu_add( adv, item_create_switch  ( _("Center Preview:"), HINT_CENTERPREVIEW, &config.center_preview, _("Off"), _("On") ) );
-    menu_add( adv, item_create_switch  ( _("Collision Check:"), HINT_COL_CHECK, &config.async_col_check, _("Sync"), _("Async") ) );
 #ifdef DEVELOPMENT    
     menu_add( adv, item_create_separator( "" ) );
     menu_add( adv, item_create_action( _("Test CPU Algorithm"), HINT_CPUALG, ACTION_MAKE_STAT ) );
@@ -475,8 +481,12 @@ void manager_delete()
     free_font( &mhfont );
     free_font( &mcfont );
 #ifdef SOUND
-    if ( wav_menu_click ) sound_chunk_free( wav_menu_click ); wav_menu_click = 0;
-    if ( wav_menu_motion ) sound_chunk_free( wav_menu_motion ); wav_menu_motion = 0;
+    if ( wav_menu_click )
+	    sound_chunk_free( wav_menu_click );
+    wav_menu_click = 0;
+    if ( wav_menu_motion )
+	    sound_chunk_free( wav_menu_motion );
+    wav_menu_motion = 0;
 #endif
 }
 /*
