@@ -459,7 +459,7 @@ void draw_3dframe( SDL_Surface *surf, int cx, int cy, int w, int h, int border )
     }
     DEST( surf, cx - border, cy - border, w + border * 2, h + border * 2 );
     SOURCE( frame, 0, 0 );
-    alpha_blit_surf( 48 );
+    alpha_blit_surf( 64 );
     /* bright part */
     FULL_DEST( frame ); fill_surf ( 0xff0000 );
     DEST( frame, w + border, border, border, h + border ); fill_surf( 0xffffff );
@@ -485,7 +485,7 @@ void draw_3dframe( SDL_Surface *surf, int cx, int cy, int w, int h, int border )
     FULL_DEST( contents ); fill_surf( 0x0 );
     DEST( surf, cx, cy, w, h );
     SOURCE( contents, 0, 0 );
-    alpha_blit_surf( 96 );
+    alpha_blit_surf( 48 );
 
     SDL_FreeSurface( contents );
     SDL_FreeSurface( frame ); 
@@ -530,17 +530,20 @@ Font* load_font(char *fname)
     /* table */
     file = fopen(path, "r");
     fseek(file, -1, SEEK_END);
-    fread(&fnt->offset, 1, 1, file);
+    if (fread(&fnt->offset, 1, 1, file) != 1)
+	    fprintf(stderr,"Error reading font\n");
 #ifdef SDL_DEBUG
     printf("offset: %i\n", fnt->offset);
 #endif
     fseek(file, -2, SEEK_END);
-    fread(&fnt->length, 1, 1, file);
+    if (fread(&fnt->length, 1, 1, file) != 1)
+	    fprintf(stderr,"Error reading font\n");
 #ifdef SDL_DEBUG
     printf("number: %i\n", fnt->length);
 #endif
     fseek(file, -2 - fnt->length, SEEK_END);
-    fread(fnt->char_width, 1, fnt->length, file);
+    if (fread(fnt->char_width, 1, fnt->length, file) != fnt->length)
+	    fprintf(stderr,"Error reading font\n");
 #ifdef SDL_DEBUG
     printf("letter width: %i\n", fnt->length);
     for (i = 0; i < fnt->length; i++)
@@ -1338,7 +1341,7 @@ int get_time()
 */
 void reset_timer()
 {
-    last_time = SDL_GetTicks();
+	cur_time = last_time = SDL_GetTicks();
 }
 
 void fade_screen( int type, int length )
