@@ -34,6 +34,7 @@ Sound_Chunk *wav_click = 0;
 #endif
 Bowl *bowls[BOWL_COUNT]; /* all bowls */
 int  *next_blocks = NULL, next_blocks_size = 0; /* all receive same blocks */
+int last_generated_block = -1; /* block id of last block generated when filling bag */
 
 extern Sdl sdl;
 extern Config config;
@@ -157,7 +158,7 @@ Id == -1 means to use a random background.
 Copy result to offscreen and screen. Draws bowl contents.
 ====================================================================
 */
-enum { BACK_COUNT = 6 };
+enum { BACK_COUNT = 4 };
 void tetris_recreate_bkgnd( int id )
 {
     SDL_Surface *pic = 0;
@@ -189,9 +190,9 @@ void tetris_recreate_bkgnd( int id )
             bowl_draw_frames( bowls[i] );
     /* draw to offscreen */
     FULL_DEST( offscreen ); FULL_SOURCE( bkgnd ); blit_surf();
-    /* add logo if place */
+    /* add logo if place
     if ( config.gametype <= 2 )
-        tetris_draw_logo();
+        tetris_draw_logo(); */
     /* draw bowl contents */
     for ( i = 0; i < BOWL_COUNT; i++ )
         if ( bowls[i] )
@@ -232,15 +233,27 @@ void tetris_create()
 }
 void tetris_delete()
 {
-    if ( logo ) SDL_FreeSurface( logo ); logo = 0;
-    if ( blocks ) SDL_FreeSurface( blocks ); blocks = 0;
-    if ( qmark ) SDL_FreeSurface( qmark ); qmark = 0;
+    if ( logo )
+	    SDL_FreeSurface( logo );
+    logo = 0;
+    if ( blocks )
+	    SDL_FreeSurface( blocks );
+    blocks = 0;
+    if ( qmark )
+	    SDL_FreeSurface( qmark );
+    qmark = 0;
     free_font( &font );
     free_font( &large_font );
-    if ( offscreen ) SDL_FreeSurface( offscreen ); offscreen = 0;
-    if ( bkgnd ) SDL_FreeSurface( bkgnd ); bkgnd = 0;
+    if ( offscreen )
+	    SDL_FreeSurface( offscreen );
+    offscreen = 0;
+    if ( bkgnd )
+	    SDL_FreeSurface( bkgnd );
+    bkgnd = 0;
 #ifdef SOUND        
-    if ( wav_click ) sound_chunk_free( wav_click ); wav_click = 0;
+    if ( wav_click )
+	    sound_chunk_free( wav_click );
+    wav_click = 0;
 #endif        
 }
 
@@ -255,18 +268,20 @@ int  tetris_init()
 {
 	/* create block buffer with several bags each containing all 7 
 	 * tetrominoes permuted randomly */
+	last_generated_block = -1;
 	next_blocks_size = BLOCK_BAG_COUNT * BLOCK_COUNT;
 	next_blocks = calloc( next_blocks_size, sizeof(int) );
-	fill_random_block_bags( next_blocks, BLOCK_BAG_COUNT );
+	fill_random_block_bags( next_blocks, BLOCK_BAG_COUNT, config.modern );
 
     /* create bowls according to the gametype */
     switch ( config.gametype ) {
         case GAME_DEMO:
-            bowls[0] = bowl_create( 70, 0, 460, 300, blocks, qmark, "Demo", 0 );
+            bowls[0] = bowl_create( 220, 0, 530, 200, blocks, qmark, "Demo", 0 );
             break;
         case GAME_CLASSIC:
+        case GAME_TRAINING:
         case GAME_FIGURES:
-            bowls[0] = bowl_create( 70, 0, 460, 300, blocks, qmark, config.player1.name, &config.player1.controls );
+            bowls[0] = bowl_create( 220, 0, 530, 200, blocks, qmark, config.player1.name, &config.player1.controls );
             break;
         case GAME_VS_HUMAN:
         case GAME_VS_CPU:
@@ -324,6 +339,22 @@ void tetris_clear()
     shrapnells_delete();
 }
 
+/** Display FPS in console */
+void show_fps(int fps) {
+	SDL_Rect r = {0,0,40,20};
+	char str[32];
+	sprintf(str,"%d",fps);
+	if (bowls[0]->font && sdl.screen) {
+		DEST( sdl.screen, r.x, r.y , r.w, r.h );
+		SOURCE( offscreen, r.x, r.y );
+		blit_surf();
+
+		bowls[0]->font->align = ALIGN_X_LEFT | ALIGN_Y_TOP;
+		write_text( bowls[0]->font, sdl.screen, 4, 4, str, OPAQUE );
+		add_refresh_rect(r.x,r.y,r.w,r.h); /* XXX fixed size */
+	}
+}
+
 /*
 ====================================================================
 Run a successfully initated game.
@@ -334,7 +365,6 @@ void tetris_run()
     SDL_Event event;
     int leave = 0;
     int i;
-    int fps_delay = 0;
     int ms;
     int request_pause = 0;
     int game_over = 0;
@@ -342,8 +372,9 @@ void tetris_run()
     int bowl_count; /* number of active bowls */
     char sshot_str[128];
     int screenshot_id = 0;
-    int gain_multiplayer_bonus = 0;
-    int escape = 0;
+    int fps = 0, fpsStart, fpsCycles;
+    int maxDelay;
+    Uint32 cycle_start, delay;
     
     /* count number of bowls */
     bowl_count = 0;
@@ -352,18 +383,21 @@ void tetris_run()
             bowl_count++;
     
     SDL_ShowCursor( 0 );
-    /* delay */
-    switch ( config.fps ) {
-        case 1: fps_delay = 20; break;
-        case 2: fps_delay = 10; break;
-        case 3: fps_delay = 5; break;
-    }
+
+	fpsStart = SDL_GetTicks();
+	fpsCycles = 0;
+	if (config.fps == 1)
+		maxDelay = 20;
+	else
+		maxDelay = 17;
+
     /* main loop */
     fade_screen( FADE_IN, FADE_DEF_TIME );
     reset_timer();
     event_reset();
     while ( !leave && !term_game ) {
-        if ( config.fps ) SDL_Delay( fps_delay );
+	    cycle_start = SDL_GetTicks();
+
         if ( event_poll( &event ) ) {
             switch ( event.type ) {
 		case SDL_QUIT:
@@ -381,7 +415,6 @@ void tetris_run()
                         request_pause = 1;
                     else switch ( event.key.keysym.sym ) {
                         case SDLK_ESCAPE: 
-                            escape = 1;
                             if ( confirm( large_font, _("End Game? y/n"), CONFIRM_YES_NO ) ) 
                                 for ( i = 0; i < BOWL_COUNT; i++ )
                                     if ( bowls[i] && !bowls[i]->game_over )
@@ -452,23 +485,34 @@ void tetris_run()
                 game_over = 1;
             else
                 game_over = 0;
-            if ( game_over && bowl_count > 1 && !escape )
-                gain_multiplayer_bonus = 1;
-        }
-        /* the last bowl in multiplayer gains additional 100,000 score */
-        if ( gain_multiplayer_bonus ) {
-            gain_multiplayer_bonus = 0;
-            for ( i = 0; i < BOWL_COUNT; i++ )
-                if ( bowls[i] && !bowls[i]->game_over )
-                    counter_add( &bowls[i]->score, 50000 );
         }
+
+	/* stats */
+	fpsCycles++;
+	if (fpsStart < SDL_GetTicks())
+		fps = ((10000 * fpsCycles / (SDL_GetTicks() - fpsStart))+5)/10;
+	if (fpsCycles > 100) {
+		fpsCycles = 0;
+		fpsStart = SDL_GetTicks();
+	}
+	show_fps(fps);
+
+	/* limit frame rate */
+	delay = maxDelay - (SDL_GetTicks() - cycle_start);
+	if (delay < 1)
+		delay = 1;
+	if (delay > maxDelay)
+		delay = maxDelay;
+	SDL_Delay(delay);
     }
     fade_screen( FADE_OUT, FADE_DEF_TIME );
     /* highscore entries */
     chart_clear_new_entries();
     for ( i = 0; i < BOWL_COUNT; i++ )
         if ( bowls[i] ) 
-            chart_add( chart_set_query( gametype_ids[config.gametype] ), bowls[i]->name, bowls[i]->level, counter_get( bowls[i]->score ) );
+            chart_add( chart_set_query( gametype_ids[config.gametype] ),
+        		    bowls[i]->name, bowls[i]->level,
+			    counter_get( bowls[i]->score ) );
     SDL_ShowCursor( 1 );
 }
 
